@@ -20,7 +20,8 @@ FP::Abstract::Sequence::t -- tests for FP::Abstract::Sequence
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
