@@ -105,7 +105,8 @@ L<FP::List>, L<FP::Lazy>
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
