@@ -115,7 +115,8 @@ C<:tries>: L<FP::Trie>
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
@@ -128,7 +129,7 @@ package FunctionalPerl;
 
 use strict; use warnings; use warnings FATAL => 'uninitialized';
 
-our $VERSION= "0.72.13";
+our $VERSION= "0.72.14";
 
 
 # Export tag to modules and/or other tags; each module will be
