@@ -18,7 +18,8 @@ PXML::Util - utility functions for PXML trees
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
